[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - pygeoip.GeoIPError
  - pygeoip.GeoIP
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - pygeoip._GeoIPMetaclass